##  Viewing Survey Results
To view the results of a live or completed survey, click its title. This opens the Insight tab, where you can view survey results directly in the survey editor, including key metrics like fact sheets and survey scope, reminders sent, and survey progress status.
**Remember**
Once the survey goes live, the Scope, Design, Preview, and Share tabs become inaccessible until the survey run is finished.
Additional options are available in the top-right corner, allowing you to finish the survey, view metrics from previous runs, send reminders, check for changes in the survey scope to identify and update any new fact sheets or recipients, or download the results as a CSV file.
![Viewing Survey Results](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755eb827a441014a767f6da9ceb4857_LowRes.png)
Viewing Survey Results
Select a fact sheet from the left navigation pane to view the respondents' answers. You see detailed responses, including who updated the fact sheet.
Click the Fact Sheets and Scope tile to view which recipients have completed the survey, the fact sheets they are responsible for, and how many of those fact sheets each recipient has completely answered. The completed information is highlighted in green.
![Survey Recipient and Fact Sheet Completion Details of a Survey Run](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274376b27a441014948882244c1bbbf1_LowRes.png)
Survey Recipient and Fact Sheet Completion Details of a Survey Run
You can also download the survey results as a spreadsheet by clicking Download .CSV from the three-dot menu in the top-right corner. The spreadsheet includes additional details, such as the reply status for each fact sheet, which can be one of the following:
  * New: No question has been answered yet.
  * In Progress: The respondent has started answering but hasn't finished the fact sheet.
  * Done: All the questions related to the fact sheet are answered.
  * Obsolete: The fact sheet is no longer included in the survey. This can happen if:
    * There is no user subscribed to the fact sheet. In this case, the survey cannot be delivered to anyone, and the fact sheet is marked as obsolete.
    * The attribute in the fact sheet has changed, resulting in the fact sheet no longer meeting the survey’s filter criteria. For example, if a survey targets application fact sheets with insufficient functional fit, and a fact sheet initially matching this filter is later updated to have perfect functional fit, it will fall outside the defined scope of the survey.
    * The fact sheet is archived.
